Enum futures_shuttle::ShuttleError
[−]
[src]
pub enum ShuttleError {
Corrupted,
Stopped,
}Describes the possible error state of the Shuttle object.
Variants
CorruptedThis object' internal state is corrupted and it cannot be used anymore.
StoppedThis Shuttle has been stopped (the other side has been dropped and disappeared)