Struct futures_shuttle::ShuttleWait
[−]
[src]
#[must_use = "futures do nothing unless polled"]pub struct ShuttleWait<T> { /* fields omitted */ }
ShuttleWait object is a Future that waits for Shuttle to arrive back. I.e. it completes
when the other side calls send on its object and the ownership turns to this object.
ShuttleWait is created when Shuttle is converted into Future (it implements IntoFuture)
and it consumes the Shuttle object.
When the future completes it yields the Shuttle object back.